@@ -5,17 +5,21 @@ from collections import Iterator
 class DatasetInfo:
     def __init__(self, info_addr):
         with open(info_addr) as f:
-            info = json.load(f)
-            self.version = info['version']
-            self.task = info['task']
-            self.size = info['size']
-            self.splits = info['splits']
+            self.info = json.load(f)
+            for info_key, info_value in self.info.items():
+                setattr(self, info_key, info_value)
 
-class BaseDataset(Iterator):
+    def __repr__(self):
+        return '\n'.join([f'{key}: {value}' for key, value in self.info.items()])
 
-    def __init__(self, iterator, info, num_lines):
+    def __str__(self):
+        return '\n'.join([f'{key}: {value}' for key, value in self.info.items()])
+
+
+class BaseIterator(Iterator):
+
+    def __init__(self, iterator, num_lines):
         self.iterator = iterator
-        self.info = info
         self.num_lines = num_lines
         self.current_pos = 0
 
@@ -43,14 +47,22 @@ class BaseDataset(Iterator):
         return self.current_pos
 
 
-class SplittedDataset:
+class BaseDataset:
     """Abstract dataset class for dataset-like object, like list and array.
     All datasets(sub-classes) should inherit.
     Args:
         data (list, array, tuple): dataset-like object
     """
 
-    def __init__(self, train=None, test=None, dev=None):
-        self.train = train
-        self.test = test
-        self.dev = dev
+    def __init__(self, info):
+        self.info = info
+
+    def set_iterators(self, iterators_dict):
+        if type(iterators_dict) != dict:
+            self.data = iterators_dict
+        else:
+            for iterator_name, iterator_func in iterators_dict.items():
+                setattr(self, iterator_name, iterator_func)
+
+    def __getattr__(self, attr):
+        raise AttributeError("'this dataset has no {} attribute. valid attributes : {}".format(attr, list(self.__dict__.keys())))
\ No newline at end of file
